<!doctype html>
<html lang="en">

<body>

Dear <b>{{TONAME}}</b>,<br/>
Your {{DOMAIN}} web hosting account exceeded one or more of its resources within the last {{PERIOD}}.<br/><br/>

{% if epf %}Exceeded the maximum of {{lep}} concurrent website connections. Your website was not available {{epf}} times because of this problem.<br/>
{% endif %}{% if pmemf %}Exceeded the physical memory limit of {{lpmem}}KB. Your website was not available {{pmemf}} times because of this problem.<br/>
{% endif %}{% if vmemf %}Exceeded the virtual memory limit of {{lvmem}}KB. Your website was not available {{vmemf}} times because of this problem.<br/>
{% endif %}{% if nprocf %}Exceeded the number of processes limit of {{lnproc}}. Your website was not available {{nprocf}} times because of this problem.<br/>
{% endif %}{% if cpuf %}You reached limit of {{lcpu}} of total server CPU usage {{cpuf}} times. Your website was forced to load slower to reduce its CPU usage.<br/>
{% endif %}{% if iof %}You reached limit of {{lio}}KB/s disk io rate {{iof}} times. The disk io speed for your account was slowed as a result of this problem.<br/>
{% endif %}{% if iopsf %}You reached limit of {{liops}} I/O operations {{iopsf}} times. The disk io speed for your account was slowed as a result of this problem.<br/>
{% endif %}

<br/><br/>
To view full details about your web hosting account's resource usage, including the time of each incident listed above, please click the link below and log into your hosting control panel, then click the "Resource Usage" link.
{% if LOGIN_URL is defined %}{{LOGIN_URL}}{% else %}http://{{DOMAIN}}:2083{% endif %}<br/>

If your account is regularly exceeding it's available resources, please consider upgrading to a higher level hosting plan that includes more resources. If you have any questions or need help with anything, just reply to this email and let us know.<br/><br/>
Sincerely,<br/>
Your Friendly Web Hosting Support Team
</body>
</html>
