<!doctype html>
<html lang="en">

<body>
Dear <b>{{TONAME}}</b>,</br>

Your reseller account "{{RESELLER_USERNAME}}" exceeded one or more of its resources within the last {{PERIOD}}.</br>

{% if epf %}Exceeded the maximum of {{lep}} concurrent website connections. Your customers’ websites were not available {{epf}} times because of this problem.</br>
{% endif %}{% if pmemf %}Exceeded the physical memory limit of {{lpmem}}KB. Your customers’ websites might have failed {{pmemf}} times because of this problem.</br>
{% endif %}{% if nprocf %}Exceeded the number of processes limit of {{lnproc}}. Your customers’ websites might have failed {{nprocf}} times because of this problem.</br>
{% endif %}{% if cpuf %}You reached limit of {{lcpu}} of total server CPU usage {{cpuf}} times. Your customers’ websites were forced to load slower to reduce its CPU usage.</br>
{% endif %}{% if iof %}You reached limit of {{lio}}KB/s disk io rate {{iof}} times. The disk io speed for your customers’ websites were slowed as a result of this problem.</br>
{% endif %}{% if iopsf %}You reached limit of {{liops}} I/O operations {{iopsf}} times. The disk io speed for your customers’ websites were slowed as a result of this problem.</br>
{% endif %}</br></br>

* We do not track the exact list of affected sites. Sites accessed the time limit was hit are the one that get affected.</br>
</body>
</html>