<!doctype html>
<html lang="en">

<body>

Dear <b>{{TONAME}}</b>,<br/>
Accounts that belong to "{{RESELLER_USERNAME}}" experienced issues in the past {{PERIOD}}<br/><br/>

{{STATS_HTML}}

<br/>
Sincerely,<br/>
Your Friendly Web Hosting Support Team
</body>
</html>
